@@ -1,8 +1,8 @@
+use polars_buffer::Buffer;
 use polars_error::{PolarsResult, polars_bail, polars_err};
 
 use super::{Array, Splitable, new_empty_array, new_null_array};
 use crate::bitmap::Bitmap;
-use crate::buffer::Buffer;
 use crate::datatypes::{ArrowDataType, Field, UnionMode};
 use crate::scalar::{Scalar, new_scalar};
 
@@ -247,9 +247,9 @@ impl UnionArray {
     pub unsafe fn slice_unchecked(&mut self, offset: usize, length: usize) {
         debug_assert!(offset + length <= self.len());
 
-        self.types.slice_unchecked(offset, length);
+        self.types.slice_in_place_unchecked(offset..offset + length);
         if let Some(offsets) = self.offsets.as_mut() {
-            offsets.slice_unchecked(offset, length)
+            offsets.slice_in_place_unchecked(offset..offset + length)
         }
         self.offset += offset;
     }
