@@ -245,6 +245,32 @@ pub(super) fn arg_sort(s: &Column, descending: bool, nulls_last: bool) -> Polars
         .into_column())
 }
 
+pub(super) fn min_by(s: &[Column]) -> PolarsResult<Column> {
+    assert!(s.len() == 2);
+    let input = &s[0];
+    let by = &s[1];
+    if input.len() != by.len() {
+        polars_bail!(ShapeMismatch: "'by' column in `min_by` operation has incorrect length (got {}, expected {})", by.len(), input.len());
+    }
+    match by.as_materialized_series().arg_min() {
+        Some(idx) => Ok(input.new_from_index(idx, 1)),
+        None => Ok(Series::new_null(input.name().clone(), 1).into_column()),
+    }
+}
+
+pub(super) fn max_by(s: &[Column]) -> PolarsResult<Column> {
+    assert!(s.len() == 2);
+    let input = &s[0];
+    let by = &s[1];
+    if input.len() != by.len() {
+        polars_bail!(ShapeMismatch: "'by' column in `max_by` operation has incorrect length (got {}, expected {})", by.len(), input.len());
+    }
+    match by.as_materialized_series().arg_max() {
+        Some(idx) => Ok(input.new_from_index(idx, 1)),
+        None => Ok(Series::new_null(input.name().clone(), 1).into_column()),
+    }
+}
+
 pub(super) fn product(s: &Column) -> PolarsResult<Column> {
     // @scalar-opt
     s.as_materialized_series()
@@ -794,26 +820,32 @@ pub(super) fn corr(s: &[Column], method: IRCorrelationMethod) -> PolarsResult<Co
         let a = a.drop_nulls();
         let b = b.drop_nulls();
 
-        let a_rank = a
-            .as_materialized_series()
-            .rank(
-                RankOptions {
-                    method: RankMethod::Average,
-                    ..Default::default()
-                },
-                None,
-            )
-            .into();
-        let b_rank = b
-            .as_materialized_series()
-            .rank(
-                RankOptions {
-                    method: RankMethod::Average,
-                    ..Default::default()
-                },
-                None,
-            )
-            .into();
+        let a_rank = a.as_materialized_series().rank(
+            RankOptions {
+                method: RankMethod::Average,
+                ..Default::default()
+            },
+            None,
+        );
+        let b_rank = b.as_materialized_series().rank(
+            RankOptions {
+                method: RankMethod::Average,
+                ..Default::default()
+            },
+            None,
+        );
+
+        // Because rank results in f64, we may need to restore the dtype
+        let a_rank = if a.dtype().is_float() {
+            a_rank.cast(a.dtype())?.into()
+        } else {
+            a_rank.into()
+        };
+        let b_rank = if b.dtype().is_float() {
+            b_rank.cast(b.dtype())?.into()
+        } else {
+            b_rank.into()
+        };
 
         pearson_corr(&[a_rank, b_rank])
     }
