@@ -1,5 +1,6 @@
 use std::cmp;
 use std::iter::Iterator;
+use std::num::NonZeroUsize;
 use std::sync::Arc;
 
 use polars_buffer::Buffer;
@@ -33,6 +34,9 @@ pub fn read_until_start_and_infer_schema(
     mut inspect_first_content_row_fn: Option<InspectContentFn<'_>>,
     reader: &mut CompressedReader,
 ) -> PolarsResult<(Schema, Buffer<u8>)> {
+    // It's better to be above than below here.
+    const ESTIMATED_BYTES_PER_ROW: usize = 200;
+
     #[derive(Copy, Clone)]
     enum State {
         // Ordered so that all states only happen after the ones before it.
@@ -73,12 +77,32 @@ pub fn read_until_start_and_infer_schema(
     let infer_schema_length = options.infer_schema_length.unwrap_or(usize::MAX);
 
     let mut header_line = None;
-    let mut content_lines = Vec::with_capacity(options.infer_schema_length.unwrap_or(256));
+    let mut content_lines = Vec::with_capacity(options.infer_schema_length.unwrap_or_else(|| {
+        reader
+            .total_len_estimate()
+            .saturating_div(ESTIMATED_BYTES_PER_ROW)
+    }));
+
+    // In the compressed case `reader.read_next_slice` has to copy the previous leftover into a new
+    // `Vec` which would lead to quadratic copying if we don't factor in `infer_schema_length` into
+    // the initial read size. We have to retain the row memory for schema inference and also for
+    // actual morsel generation. If `infer_schema_length` is set to `None` we will have to read the
+    // full input anyway so we can do so once and avoid re-copying.
+    let initial_read_size = options
+        .infer_schema_length
+        .map(|isl| {
+            cmp::max(
+                CompressedReader::initial_read_size(),
+                isl.saturating_mul(ESTIMATED_BYTES_PER_ROW),
+            )
+        })
+        .unwrap_or(usize::MAX);
 
     let leftover = for_each_line_from_reader(
         &options.parse_options,
         true,
         prev_leftover,
+        initial_read_size,
         reader,
         |mem_slice_line| {
             let line = &*mem_slice_line;
@@ -179,12 +203,23 @@ fn for_each_line_from_reader(
     parse_options: &CsvParseOptions,
     is_file_start: bool,
     mut prev_leftover: Buffer<u8>,
+    initial_read_size: usize,
     reader: &mut CompressedReader,
     mut line_fn: impl FnMut(Buffer<u8>) -> PolarsResult<LineUse>,
 ) -> PolarsResult<Buffer<u8>> {
     let mut is_first_line = is_file_start;
 
-    let mut read_size = CompressedReader::initial_read_size();
+    let fixed_read_size = std::env::var("POLARS_FORCE_CSV_INFER_CHUNK_SIZE")
+        .map(|x| {
+            x.parse::<NonZeroUsize>()
+                .unwrap_or_else(|_| {
+                    panic!("invalid value for POLARS_FORCE_CSV_INFER_CHUNK_SIZE: {x}")
+                })
+                .get()
+        })
+        .ok();
+
+    let mut read_size = fixed_read_size.unwrap_or(initial_read_size);
     let mut retain_offset = None;
 
     loop {
@@ -233,8 +268,12 @@ fn for_each_line_from_reader(
             match line_fn(line_to_sub_slice(prev_line))? {
                 LineUse::ConsumeDiscard => debug_assert!(retain_offset.is_none()),
                 LineUse::ConsumeKeep => {
-                    retain_offset
-                        .get_or_insert(prev_line.as_ptr() as usize - slice.as_ptr() as usize);
+                    if retain_offset.is_none() {
+                        let retain_start_offset =
+                            prev_line.as_ptr() as usize - slice.as_ptr() as usize;
+                        prev_leftover = slice.clone().sliced(retain_start_offset..);
+                        retain_offset = Some(0);
+                    }
                 },
                 LineUse::Done => {
                     should_ret = true;
@@ -244,15 +283,16 @@ fn for_each_line_from_reader(
             prev_line = next_line;
         }
 
-        let mut unconsumed_offset = prev_line.as_ptr() as usize - slice.as_ptr() as usize;
+        let mut unconsumed_offset = prev_line.as_ptr() as usize - effective_slice.as_ptr() as usize;
 
         // EOF file reached, the last line will have no continuation on the next call to
         // `read_next_slice`.
-        if bytes_read == 0 {
+        if bytes_read < read_size {
             match line_fn(line_to_sub_slice(prev_line))? {
                 LineUse::ConsumeDiscard => {
+                    debug_assert!(retain_offset.is_none());
                     unconsumed_offset += prev_line.len();
-                    if slice.get(unconsumed_offset) == Some(&parse_options.eol_char) {
+                    if effective_slice.get(unconsumed_offset) == Some(&parse_options.eol_char) {
                         unconsumed_offset += 1;
                     }
                 },
@@ -261,8 +301,15 @@ fn for_each_line_from_reader(
             should_ret = true;
         }
 
-        if retain_offset.is_some() {
-            prev_leftover = slice;
+        if let Some(offset) = &mut retain_offset {
+            if *offset == 0 {
+                // `unconsumed_offset` was computed with the full `slice` as base reference
+                // compensate retained offset.
+                *offset = unconsumed_offset - (slice.len() - prev_leftover.len());
+            } else {
+                prev_leftover = slice;
+                *offset += unconsumed_offset;
+            }
         } else {
             // Since `read_next_slice` has to copy the leftover bytes in the decompression case,
             // it's more efficient to hand in as little as possible.
@@ -270,11 +317,10 @@ fn for_each_line_from_reader(
         }
 
         if should_ret {
-            let leftover = prev_leftover.sliced(retain_offset.unwrap_or(0)..);
-            return Ok(leftover);
+            return Ok(prev_leftover);
         }
 
-        if read_size < CompressedReader::ideal_read_size() {
+        if read_size < CompressedReader::ideal_read_size() && fixed_read_size.is_none() {
             read_size *= 4;
         }
     }
