@@ -22,5 +22,5 @@ mod write_impl;
 mod writer;
 
 pub use options::{CsvWriterOptions, QuoteStyle, SerializeOptions};
-pub use write_impl::{CsvSerializer, write_bom, write_csv_header};
+pub use write_impl::{CsvSerializer, UTF8_BOM, csv_header};
 pub use writer::{BatchedWriter, CsvWriter};
