@@ -2,21 +2,33 @@ use std::fmt::{Debug, Formatter};
 use std::fs::File;
 use std::sync::Arc;
 
-use arrow::buffer::Buffer;
+use polars_buffer::Buffer;
 use polars_core::error::{PolarsResult, feature_gated};
 use polars_error::polars_err;
 use polars_io::cloud::CloudOptions;
 #[cfg(feature = "cloud")]
 use polars_io::file_cache::FileCacheEntry;
-#[cfg(feature = "cloud")]
 use polars_io::utils::byte_source::{DynByteSource, DynByteSourceBuilder};
 use polars_io::{expand_paths, expand_paths_hive, expanded_from_single_directory};
-use polars_utils::mmap::MemSlice;
+use polars_utils::mmap::MMapSemaphore;
 use polars_utils::pl_path::PlRefPath;
 use polars_utils::pl_str::PlSmallStr;
+#[cfg(feature = "serde")]
+use serde::{Deserialize, Deserializer, Serialize, Serializer};
 
 use super::UnifiedScanArgs;
 
+#[cfg(feature = "serde")]
+fn serialize_paths<S: Serializer>(paths: &Buffer<PlRefPath>, s: S) -> Result<S::Ok, S::Error> {
+    paths.as_slice().serialize(s)
+}
+
+#[cfg(feature = "serde")]
+fn deserialize_paths<'de, D: Deserializer<'de>>(d: D) -> Result<Buffer<PlRefPath>, D::Error> {
+    let v: Vec<PlRefPath> = Deserialize::deserialize(d)?;
+    Ok(Buffer::from(v))
+}
+
 /// Set of sources to scan from
 ///
 /// This can either be a list of paths to files, opened files or in-memory buffers. Mixing of
@@ -25,12 +37,19 @@ use super::UnifiedScanArgs;
 #[cfg_attr(feature = "dsl-schema", derive(schemars::JsonSchema))]
 #[derive(Clone)]
 pub enum ScanSources {
+    #[cfg_attr(
+        feature = "serde",
+        serde(
+            serialize_with = "serialize_paths",
+            deserialize_with = "deserialize_paths"
+        )
+    )]
+    #[cfg_attr(feature = "dsl-schema", schemars(with = "Vec<PlRefPath>"))]
     Paths(Buffer<PlRefPath>),
-
     #[cfg_attr(any(feature = "serde", feature = "dsl-schema"), serde(skip))]
     Files(Arc<[File]>),
     #[cfg_attr(any(feature = "serde", feature = "dsl-schema"), serde(skip))]
-    Buffers(Arc<[MemSlice]>),
+    Buffers(Arc<[Buffer<u8>]>),
 }
 
 impl Debug for ScanSources {
@@ -48,7 +67,7 @@ impl Debug for ScanSources {
 pub enum ScanSourceRef<'a> {
     Path(&'a PlRefPath),
     File(&'a File),
-    Buffer(&'a MemSlice),
+    Buffer(&'a Buffer<u8>),
 }
 
 /// A single source to scan from
@@ -56,7 +75,7 @@ pub enum ScanSourceRef<'a> {
 pub enum ScanSource {
     Path(PlRefPath),
     File(Arc<File>),
-    Buffer(MemSlice),
+    Buffer(Buffer<u8>),
 }
 
 impl ScanSource {
@@ -160,14 +179,17 @@ impl PartialEq for ScanSources {
 impl Eq for ScanSources {}
 
 impl ScanSources {
-    pub fn expand_paths(&self, scan_args: &mut UnifiedScanArgs) -> PolarsResult<Self> {
+    pub async fn expand_paths(&self, scan_args: &mut UnifiedScanArgs) -> PolarsResult<Self> {
         match self {
-            Self::Paths(paths) => Ok(Self::Paths(expand_paths(
-                paths,
-                scan_args.glob,
-                scan_args.hidden_file_prefix.as_deref().unwrap_or_default(),
-                &mut scan_args.cloud_options,
-            )?)),
+            Self::Paths(paths) => Ok(Self::Paths(
+                expand_paths(
+                    paths,
+                    scan_args.glob,
+                    scan_args.hidden_file_prefix.as_deref().unwrap_or_default(),
+                    &mut scan_args.cloud_options,
+                )
+                .await?,
+            )),
             v => Ok(v.clone()),
         }
     }
@@ -175,7 +197,7 @@ impl ScanSources {
     /// This will update `scan_args.hive_options.enabled` to `true` if the existing value is `None`
     /// and the paths are expanded from a single directory. Otherwise the existing value is maintained.
     #[cfg(any(feature = "ipc", feature = "parquet"))]
-    pub fn expand_paths_with_hive_update(
+    pub async fn expand_paths_with_hive_update(
         &self,
         scan_args: &mut UnifiedScanArgs,
     ) -> PolarsResult<Self> {
@@ -187,7 +209,8 @@ impl ScanSources {
                     scan_args.hidden_file_prefix.as_deref().unwrap_or_default(),
                     &mut scan_args.cloud_options,
                     scan_args.hive_options.enabled.unwrap_or(false),
-                )?;
+                )
+                .await?;
 
                 if scan_args.hive_options.enabled.is_none()
                     && expanded_from_single_directory(paths, expanded_paths.as_ref())
@@ -362,17 +385,17 @@ impl ScanSourceRef<'_> {
     }
 
     /// Turn the scan source into a memory slice
-    pub fn to_memslice(&self) -> PolarsResult<MemSlice> {
-        self.to_memslice_possibly_async(false, None, 0)
+    pub fn to_memslice(&self) -> PolarsResult<Buffer<u8>> {
+        self.to_buffer_possibly_async(false, None, 0)
     }
 
     #[allow(clippy::wrong_self_convention)]
     #[cfg(feature = "cloud")]
-    fn to_memslice_async<F: Fn(Arc<FileCacheEntry>) -> PolarsResult<std::fs::File>>(
+    fn to_buffer_async<F: Fn(Arc<FileCacheEntry>) -> PolarsResult<std::fs::File>>(
         &self,
         open_cache_entry: F,
         run_async: bool,
-    ) -> PolarsResult<MemSlice> {
+    ) -> PolarsResult<Buffer<u8>> {
         match self {
             ScanSourceRef::Path(path) => {
                 let file = if run_async {
@@ -385,47 +408,51 @@ impl ScanSourceRef<'_> {
                     polars_utils::open_file(path.as_std_path())?
                 };
 
-                MemSlice::from_file(&file)
+                Ok(Buffer::from_owner(MMapSemaphore::new_from_file(&file)?))
+            },
+            ScanSourceRef::File(file) => {
+                Ok(Buffer::from_owner(MMapSemaphore::new_from_file(file)?))
             },
-            ScanSourceRef::File(file) => MemSlice::from_file(file),
             ScanSourceRef::Buffer(buff) => Ok((*buff).clone()),
         }
     }
 
     #[cfg(feature = "cloud")]
-    pub fn to_memslice_async_assume_latest(&self, run_async: bool) -> PolarsResult<MemSlice> {
-        self.to_memslice_async(|entry| entry.try_open_assume_latest(), run_async)
+    pub fn to_buffer_async_assume_latest(&self, run_async: bool) -> PolarsResult<Buffer<u8>> {
+        self.to_buffer_async(|entry| entry.try_open_assume_latest(), run_async)
     }
 
     #[cfg(feature = "cloud")]
-    pub fn to_memslice_async_check_latest(&self, run_async: bool) -> PolarsResult<MemSlice> {
-        self.to_memslice_async(|entry| entry.try_open_check_latest(), run_async)
+    pub fn to_buffer_async_check_latest(&self, run_async: bool) -> PolarsResult<Buffer<u8>> {
+        self.to_buffer_async(|entry| entry.try_open_check_latest(), run_async)
     }
 
     #[cfg(not(feature = "cloud"))]
     #[allow(clippy::wrong_self_convention)]
-    fn to_memslice_async(&self, run_async: bool) -> PolarsResult<MemSlice> {
+    fn to_buffer_async(&self, run_async: bool) -> PolarsResult<Buffer<u8>> {
         match self {
             ScanSourceRef::Path(path) => {
                 let file = polars_utils::open_file(path.as_std_path())?;
-                MemSlice::from_file(&file)
+                Ok(Buffer::from_owner(MMapSemaphore::new_from_file(&file)?))
+            },
+            ScanSourceRef::File(file) => {
+                Ok(Buffer::from_owner(MMapSemaphore::new_from_file(file)?))
             },
-            ScanSourceRef::File(file) => MemSlice::from_file(file),
             ScanSourceRef::Buffer(buff) => Ok((*buff).clone()),
         }
     }
 
     #[cfg(not(feature = "cloud"))]
-    pub fn to_memslice_async_assume_latest(&self, run_async: bool) -> PolarsResult<MemSlice> {
-        self.to_memslice_async(run_async)
+    pub fn to_buffer_async_assume_latest(&self, run_async: bool) -> PolarsResult<Buffer<u8>> {
+        self.to_buffer_async(run_async)
     }
 
     #[cfg(not(feature = "cloud"))]
-    pub fn to_memslice_async_check_latest(&self, run_async: bool) -> PolarsResult<MemSlice> {
-        self.to_memslice_async(run_async)
+    pub fn to_buffer_async_check_latest(&self, run_async: bool) -> PolarsResult<Buffer<u8>> {
+        self.to_buffer_async(run_async)
     }
 
-    pub fn to_memslice_possibly_async(
+    pub fn to_buffer_possibly_async(
         &self,
         run_async: bool,
         #[cfg(feature = "cloud")] cache_entries: Option<
@@ -433,7 +460,7 @@ impl ScanSourceRef<'_> {
         >,
         #[cfg(not(feature = "cloud"))] cache_entries: Option<&()>,
         index: usize,
-    ) -> PolarsResult<MemSlice> {
+    ) -> PolarsResult<Buffer<u8>> {
         match self {
             Self::Path(path) => {
                 let file = if run_async {
@@ -444,14 +471,13 @@ impl ScanSourceRef<'_> {
                     polars_utils::open_file(path.as_std_path())?
                 };
 
-                MemSlice::from_file(&file)
+                Ok(Buffer::from_owner(MMapSemaphore::new_from_file(&file)?))
             },
-            Self::File(file) => MemSlice::from_file(file),
+            Self::File(file) => Ok(Buffer::from_owner(MMapSemaphore::new_from_file(file)?)),
             Self::Buffer(buff) => Ok((*buff).clone()),
         }
     }
 
-    #[cfg(feature = "cloud")]
     pub async fn to_dyn_byte_source(
         &self,
         builder: &DynByteSourceBuilder,
@@ -463,7 +489,9 @@ impl ScanSourceRef<'_> {
                     .try_build_from_path((*path).clone(), cloud_options)
                     .await
             },
-            Self::File(file) => Ok(DynByteSource::from(MemSlice::from_file(file)?)),
+            Self::File(file) => Ok(DynByteSource::from(Buffer::from_owner(
+                MMapSemaphore::new_from_file(file)?,
+            ))),
             Self::Buffer(buff) => Ok(DynByteSource::from((*buff).clone())),
         }
     }
