@@ -702,11 +702,12 @@ impl ProjectionPushDown {
                 schema,
                 options,
             } => process_hconcat(self, inputs, schema, options, ctx, lp_arena, expr_arena),
-            lp @ Union { .. } => process_generic(self, lp, ctx, lp_arena, expr_arena),
+            lp @ Union { .. } => process_generic(self, lp, ctx, lp_arena, expr_arena, false),
             // These nodes only have inputs and exprs, so we can use same logic.
-            lp @ Slice { .. } | lp @ Sink { .. } | lp @ SinkMultiple { .. } => {
-                process_generic(self, lp, ctx, lp_arena, expr_arena)
+            lp @ Slice { .. } | lp @ Sink { .. } => {
+                process_generic(self, lp, ctx, lp_arena, expr_arena, false)
             },
+            lp @ SinkMultiple { .. } => process_generic(self, lp, ctx, lp_arena, expr_arena, true),
             Cache { .. } => {
                 // projections above this cache will be accumulated and pushed down
                 // later
