@@ -1,6 +1,7 @@
 use bitflags::bitflags;
 use polars_core::prelude::*;
 use polars_core::utils::SuperTypeOptions;
+use polars_utils::bool::UnsafeBool;
 #[cfg(feature = "serde")]
 use serde::{Deserialize, Serialize};
 
@@ -22,17 +23,6 @@ pub struct DistinctOptionsIR {
     pub slice: Option<(i64, usize)>,
 }
 
-// a boolean that can only be set to `false` safely
-#[derive(Clone, Copy, PartialEq, Eq, Debug, Hash)]
-#[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
-#[cfg_attr(feature = "dsl-schema", derive(schemars::JsonSchema))]
-pub struct UnsafeBool(bool);
-impl Default for UnsafeBool {
-    fn default() -> Self {
-        UnsafeBool(true)
-    }
-}
-
 #[cfg(feature = "dsl-schema")]
 impl schemars::JsonSchema for FunctionFlags {
     fn schema_name() -> std::borrow::Cow<'static, str> {
@@ -190,7 +180,7 @@ impl CastingRules {
     }
 }
 
-#[derive(Clone, Copy, PartialEq, Eq, Debug, Hash)]
+#[derive(Clone, Copy, PartialEq, Eq, Debug, Hash, Default)]
 #[cfg_attr(any(feature = "serde"), derive(Serialize, Deserialize))]
 #[cfg_attr(feature = "dsl-schema", derive(schemars::JsonSchema))]
 pub struct FunctionOptions {
@@ -207,10 +197,10 @@ pub struct FunctionOptions {
 impl FunctionOptions {
     #[cfg(feature = "fused")]
     pub(crate) unsafe fn no_check_lengths(&mut self) {
-        self.check_lengths = UnsafeBool(false);
+        unsafe { self.check_lengths = UnsafeBool::new_false() };
     }
     pub fn check_lengths(&self) -> bool {
-        self.check_lengths.0
+        *self.check_lengths
     }
 
     pub fn set_elementwise(&mut self) {
@@ -290,16 +280,6 @@ impl FunctionOptions {
     }
 }
 
-impl Default for FunctionOptions {
-    fn default() -> Self {
-        FunctionOptions {
-            check_lengths: UnsafeBool(true),
-            cast_options: Default::default(),
-            flags: Default::default(),
-        }
-    }
-}
-
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 #[cfg_attr(feature = "dsl-schema", derive(schemars::JsonSchema))]
 #[derive(Clone, Copy, Debug, PartialEq, Eq, Hash)]
