@@ -4,7 +4,7 @@ use std::sync::OnceLock;
 
 use arrow::array::Array;
 use polars::chunked_array::object::ObjectArray;
-use polars::prelude::sink2::FileProviderReturn;
+use polars::prelude::file_provider::FileProviderReturn;
 use polars::prelude::*;
 use polars_core::chunked_array::object::builder::ObjectChunkedBuilder;
 use polars_core::chunked_array::object::registry::AnonymousObjectBuilder;
@@ -138,16 +138,6 @@ pub unsafe fn register_startup_deps(catch_keyboard_interrupt: bool) {
 
         polars_utils::python_convert_registry::register_converters(PythonConvertRegistry {
             from_py: FromPythonConvertRegistry {
-                partition_target_cb_result: Arc::new(|py_f| {
-                    Python::attach(|py| {
-                        Ok(Box::new(
-                            py_f.extract::<Wrap<polars_plan::dsl::PartitionTargetCallbackResult>>(
-                                py,
-                            )?
-                            .0,
-                        ) as _)
-                    })
-                }),
                 file_provider_result: Arc::new(|py_f| {
                     Python::attach(|py| {
                         Ok(Box::new(py_f.extract::<Wrap<FileProviderReturn>>(py)?.0) as _)
