@@ -10,11 +10,12 @@ use polars_lazy::dsl::Expr;
 use polars_lazy::prelude::{RankMethod, RankOptions};
 use polars_ops::chunked_array::UnicodeForm;
 use polars_ops::series::RoundMode;
-use polars_plan::dsl::{
-    as_struct, coalesce, concat_str, element, int_range, len, max_horizontal, min_horizontal, when,
+use polars_plan::dsl::functions::{
+    as_struct, coalesce, col, cols, concat_str, element, int_range, len, lit, max_horizontal,
+    min_horizontal, when,
 };
 use polars_plan::plans::{DynLiteralValue, LiteralValue, typed_lit};
-use polars_plan::prelude::{StrptimeOptions, col, cols, lit};
+use polars_plan::prelude::StrptimeOptions;
 use polars_utils::pl_str::PlSmallStr;
 use sqlparser::ast::helpers::attached_token::AttachedToken;
 use sqlparser::ast::{
@@ -2207,8 +2208,7 @@ impl SQLFunctionVisitor<'_> {
             by,
             SortMultipleOptions::default()
                 .with_order_descending_multi(descending)
-                .with_nulls_last_multi(nulls_last)
-                .with_maintain_order(true),
+                .with_nulls_last_multi(nulls_last),
         ))
     }
 
