@@ -189,10 +189,9 @@ impl StreamingQuery {
                 let morsels_sent = node_metrics.morsels_sent;
                 let max_sent = node_metrics.largest_morsel_sent;
 
-                let download_total_active_time =
-                    Duration::from_nanos(node_metrics.download_total_active_ns);
-                let download_total_bytes_requested = node_metrics.download_total_bytes_requested;
-                let download_total_bytes_received = node_metrics.download_total_bytes_received;
+                let io_total_active_time = Duration::from_nanos(node_metrics.io_total_active_ns);
+                let io_total_bytes_requested = node_metrics.io_total_bytes_requested;
+                let io_total_bytes_received = node_metrics.io_total_bytes_received;
 
                 lines.push(
                     (total_time, format!(
@@ -201,7 +200,10 @@ impl StreamingQuery {
                                  update({update_time:.2?}, n={total_updates}, max={max_update_time:.2?}), \
                                  recv(row={rows_received}, morsel={morsels_received}, max={max_received}), \
                                  sent(row={rows_sent}, morsel={morsels_sent}, max={max_sent}), \
-                                 download(total_active_time={download_total_active_time:.2?}, total_bytes_requested={download_total_bytes_requested}, total_bytes_received={download_total_bytes_received})"))
+                                 io(\
+                                    total_active_time={io_total_active_time:.2?}, \
+                                    total_bytes_requested={io_total_bytes_requested}, \
+                                    total_bytes_received={io_total_bytes_received})"))
                 );
 
                 total_query_ns += total_ns;
