@@ -303,6 +303,14 @@ fn assert_series_values_equal(
     abs_tol: f64,
     categorical_as_str: bool,
 ) -> PolarsResult<()> {
+    // When `check_dtypes` is `false` and both series are entirely null,
+    // consider them equal regardless of their underlying data types
+    if !check_dtypes && left.dtype() != right.dtype() {
+        if left.null_count() == left.len() && right.null_count() == right.len() {
+            return Ok(());
+        }
+    }
+
     let (left, right) = if categorical_as_str {
         (
             categorical_series_to_string(left)?,
@@ -321,14 +329,6 @@ fn assert_series_values_equal(
         (left, right)
     };
 
-    // When `check_dtypes` is `false` and both series are entirely null,
-    // consider them equal regardless of their underlying data types
-    if !check_dtypes && left.dtype() != right.dtype() {
-        if left.null_count() == left.len() && right.null_count() == right.len() {
-            return Ok(());
-        }
-    }
-
     let unequal = match left.not_equal_missing(&right) {
         Ok(result) => result,
         Err(_) => {
@@ -442,7 +442,7 @@ fn assert_series_nested_values_equal(
                 let s1_series = Series::new("".into(), std::slice::from_ref(&s1));
                 let s2_series = Series::new("".into(), std::slice::from_ref(&s2));
 
-                match assert_series_values_equal(
+                assert_series_values_equal(
                     &s1_series.explode(ExplodeOptions {
                         empty_as_null: true,
                         keep_nulls: true,
@@ -457,10 +457,7 @@ fn assert_series_nested_values_equal(
                     rel_tol,
                     abs_tol,
                     categorical_as_str,
-                ) {
-                    Ok(_) => continue,
-                    Err(e) => return Err(e),
-                }
+                )?
             }
         }
     } else {
@@ -474,7 +471,7 @@ fn assert_series_nested_values_equal(
             let s1_series = s1_column.as_materialized_series();
             let s2_series = s2_column.as_materialized_series();
 
-            match assert_series_values_equal(
+            assert_series_values_equal(
                 s1_series,
                 s2_series,
                 true,
@@ -483,10 +480,7 @@ fn assert_series_nested_values_equal(
                 rel_tol,
                 abs_tol,
                 categorical_as_str,
-            ) {
-                Ok(_) => continue,
-                Err(e) => return Err(e),
-            }
+            )?
         }
     }
 
