@@ -6,8 +6,7 @@ pub fn get_ideal_morsel_size() -> NonZeroUsize {
         std::env::var("POLARS_IDEAL_MORSEL_SIZE")
             .map(|x| {
                 x.parse::<NonZeroUsize>()
-                    .ok()
-                    .unwrap_or_else(|| panic!("invalid value for POLARS_IDEAL_MORSEL_SIZE: {x}"))
+                    .unwrap_or_else(|_| panic!("invalid value for POLARS_IDEAL_MORSEL_SIZE: {x}"))
             })
             .unwrap_or(const { NonZeroUsize::new(100_000).unwrap() })
     });
