@@ -15,6 +15,20 @@ source = "s3://bucket/*.parquet"
 df = pl.scan_parquet(source).filter(pl.col("id") < 100).select("id","value").collect()
 # --8<-- [end:scan_parquet_query]
 
+# --8<-- [start:storage_options_retry_configuration]
+import polars as pl
+
+pl.scan_parquet(
+    "s3://bucket/*.parquet",
+    storage_options={
+        "max_retries": 3,
+        "retry_timeout_ms": 9873,
+        "retry_init_backoff_ms": 9874,
+        "retry_max_backoff_ms": 9875,
+        "retry_base_multiplier": 3.14159,
+    },
+)
+# --8<-- [end:storage_options_retry_configuration]
 
 # --8<-- [start:scan_parquet_storage_options_aws]
 import polars as pl
