@@ -2,7 +2,7 @@ from __future__ import annotations
 
 import io
 from datetime import datetime
-from typing import IO, Any, Callable
+from typing import IO, TYPE_CHECKING, Any
 from zoneinfo import ZoneInfo
 
 import pytest
@@ -10,6 +10,9 @@ import pytest
 import polars as pl
 from polars.testing import assert_frame_equal
 
+if TYPE_CHECKING:
+    from collections.abc import Callable
+
 
 @pytest.mark.parametrize(
     ("literal_values", "expected", "cast_options"),
