@@ -2212,3 +2212,106 @@ def test_json_decode_categorical_enum(dtype: pl.DataType) -> None:
         dtype=pl.Struct({"a": dtype}),
     )
     assert_series_equal(result, expected)
+
+
+def test_str_split_regex() -> None:
+    df = pl.DataFrame({"s": ["foo1bar", "foo99bar", "foo1bar2baz"]})
+
+    out = df.select(split=pl.col("s").str.split(by=r"\d+", literal=False))
+    expected = pl.DataFrame(
+        {"split": [["foo", "bar"], ["foo", "bar"], ["foo", "bar", "baz"]]}
+    )
+
+    assert_frame_equal(out, expected)
+
+
+def test_str_split_regex_inclusive() -> None:
+    df = pl.DataFrame({"s": ["foo1bar", "foo99bar", "foo1bar2baz"]})
+
+    out = df.select(
+        split=pl.col("s").str.split(by=r"\d+", literal=False, inclusive=True)
+    )
+    expected = pl.DataFrame(
+        {"split": [["foo1", "bar"], ["foo99", "bar"], ["foo1", "bar2", "baz"]]}
+    )
+
+    assert_frame_equal(out, expected)
+
+
+def test_str_split_regex_expr() -> None:
+    df = pl.DataFrame(
+        {
+            "s": ["foo1bar", "foo bar", "foo-bar baz"],
+            "by": [r"\d", r"\s", r"-"],
+        }
+    )
+
+    out = df.select(split=pl.col("s").str.split(by=pl.col("by"), literal=False))
+    expected = pl.DataFrame(
+        {"split": [["foo", "bar"], ["foo", "bar"], ["foo", "bar baz"]]}
+    )
+
+    assert_frame_equal(out, expected)
+
+
+def test_str_split_regex_expr_inclusive() -> None:
+    df = pl.DataFrame(
+        {
+            "s": ["foo1bar", "foo bar", "foo-bar baz"],
+            "by": [r"\d", r"\s", r"-"],
+        }
+    )
+
+    out = df.select(
+        split=pl.col("s").str.split(by=pl.col("by"), literal=False, inclusive=True)
+    )
+    expected = pl.DataFrame(
+        {"split": [["foo1", "bar"], ["foo ", "bar"], ["foo-", "bar baz"]]}
+    )
+
+    assert_frame_equal(out, expected)
+
+
+def test_str_split_regex_invalid_pattern_strict_true() -> None:
+    df = pl.DataFrame({"s": ["foo1bar", "abc", "123xyz"]})
+
+    with pytest.raises(ComputeError):
+        df.select(split=pl.col("s").str.split(by="(", literal=False, strict=True))
+
+
+def test_str_split_regex_invalid_pattern_strict_false() -> None:
+    df = pl.DataFrame({"s": ["foo1bar", "abc", "123xyz"]})
+
+    out = df.select(split=pl.col("s").str.split(by="(", literal=False, strict=False))
+
+    expected = pl.DataFrame(
+        {
+            "split": pl.Series(
+                "split",
+                [None, None, None],
+                dtype=pl.List(pl.String),
+            )
+        }
+    )
+
+    assert_frame_equal(out, expected)
+
+
+def test_str_split_regex_scalar_string_expr() -> None:
+    df = pl.DataFrame({"by": [r"\d", r"\d+", r"bar"]})
+
+    out = df.select(
+        split=pl.lit("foo1bar2baz").str.split(by=pl.col("by"), literal=False)
+    )
+
+    expected = pl.DataFrame(
+        {
+            "split": [
+                ["foo", "bar", "baz"],  # split by \d
+                ["foo", "bar", "baz"],  # split by \d+
+                ["foo1", "2baz"],  # split by "bar"
+            ]
+        }
+    )
+
+    assert_frame_equal(out, expected)
