@@ -1,16 +1,18 @@
 from __future__ import annotations
 
-import itertools
 import typing
 from datetime import datetime, timedelta
 from typing import TYPE_CHECKING, Any, Literal
 
+import hypothesis.strategies as st
 import numpy as np
 import pandas as pd
 import pytest
+from hypothesis import given, settings
 
 import polars as pl
 from polars.testing import assert_frame_equal, assert_series_equal
+from polars.testing.parametric.strategies.core import dataframes
 
 if TYPE_CHECKING:
     from pathlib import Path
@@ -405,7 +407,6 @@ def test_cross_join_with_literal_column_25544() -> None:
     assert streaming_result.item() == 0
 
 
-@pytest.mark.slow
 @pytest.mark.parametrize("on", [["key"], ["key", "key_ext"]])
 @pytest.mark.parametrize("how", ["inner", "left", "right", "full"])
 @pytest.mark.parametrize("descending", [False, True])
@@ -413,7 +414,8 @@ def test_cross_join_with_literal_column_25544() -> None:
 @pytest.mark.parametrize("nulls_equal", [False, True])
 @pytest.mark.parametrize("coalesce", [None, True, False])
 @pytest.mark.parametrize("maintain_order", ["none", "left_right", "right_left"])
-@pytest.mark.parametrize("ideal_morsel_size", [1, 1000])
+@given(data=st.data())
+@settings(max_examples=10)
 def test_merge_join(
     on: list[str],
     how: JoinStrategy,
@@ -422,18 +424,18 @@ def test_merge_join(
     nulls_equal: bool,
     coalesce: bool | None,
     maintain_order: MaintainOrderJoin,
-    ideal_morsel_size: int,
-    monkeypatch: pytest.MonkeyPatch,
+    data: st.DataObject,
 ) -> None:
-    max_examples = 10
-    key_value_set = pl.Series([None] * 5 + list(range(5)), dtype=pl.Int32)
     check_row_order = maintain_order in {"left_right", "right_left"}
-    monkeypatch.setenv("POLARS_IDEAL_MORSEL_SIZE", str(ideal_morsel_size))
 
-    def sample_keys(height: int, seed: int) -> pl.Series:
-        return key_value_set.sample(
-            height, with_replacement=True, shuffle=True, seed=seed
-        )
+    df_st = dataframes(min_cols=len(on), max_cols=len(on), allowed_dtypes=[pl.Int16])
+    left_df = data.draw(df_st)
+    right_df = data.draw(df_st)
+
+    left = left_df.rename(dict(zip(left_df.columns, ["key", "key_ext"], strict=False)))
+    right = right_df.rename(
+        dict(zip(right_df.columns, ["key", "key_ext"], strict=False))
+    )
 
     def df_sorted(df: pl.DataFrame) -> pl.LazyFrame:
         return (
@@ -448,39 +450,20 @@ def test_merge_join(
             .set_sorted(on, descending=descending, nulls_last=nulls_last)
         )
 
-    seed = 0
-    for height, _ in itertools.product([0, 1, 5, 10], range(max_examples)):
-        # Use random testing, because hypothesis does not work well with
-        # monkeypatch.
+    q = df_sorted(left).join(
+        df_sorted(right),
+        on=on,
+        how=how,
+        nulls_equal=nulls_equal,
+        coalesce=coalesce,
+        maintain_order=maintain_order,
+    )
+    dot = q.show_graph(engine="streaming", plan_stage="physical", raw_output=True)
+    expected = q.collect(engine="in-memory")
+    actual = q.collect(engine="streaming")
 
-        df_left = pl.DataFrame(
-            {
-                "key": sample_keys(height, seed),
-                "key_ext": sample_keys(height, seed + 1),
-            },
-        ).with_row_index()
-        df_right = pl.DataFrame(
-            {
-                "key": sample_keys(height, seed + 2),
-                "key_ext": sample_keys(height, seed + 3),
-            },
-        ).with_row_index()
-        seed += 4
-
-        q = df_sorted(df_left).join(
-            df_sorted(df_right),
-            on=on,
-            how=how,
-            nulls_equal=nulls_equal,
-            coalesce=coalesce,
-            maintain_order=maintain_order,
-        )
-        dot = q.show_graph(engine="streaming", plan_stage="physical", raw_output=True)
-        expected = q.collect(engine="in-memory")
-        actual = q.collect(engine="streaming")
-
-        assert "merge-join" in typing.cast("str", dot), "merge-join not used in plan"
-        assert_frame_equal(actual, expected, check_row_order=check_row_order)
+    assert "merge-join" in typing.cast("str", dot), "merge-join not used in plan"
+    assert_frame_equal(actual, expected, check_row_order=check_row_order)
 
 
 @pytest.mark.parametrize(
@@ -562,11 +545,10 @@ def test_join_dtypes(
     assert_frame_equal(actual, expected, check_row_order=False)
 
 
-@pytest.mark.parametrize("ignore_nulls", [False, True])
-def test_merge_join_exprs(ignore_nulls: bool) -> None:
+def test_merge_join_exprs() -> None:
     left = pl.LazyFrame(
         {
-            "key": ["zzzaaa", "zzzaaaa", "zzzcaaa"],
+            "key": ["", "a", "c"],
             "key_ext": [1, 2, 3],
             "value": [1, 2, 3],
         }
@@ -582,9 +564,7 @@ def test_merge_join_exprs(ignore_nulls: bool) -> None:
     q = left.join(
         right,
         left_on="key",
-        right_on=pl.concat_str(
-            pl.lit("zzz"), pl.col("key"), pl.lit("aaa"), ignore_nulls=ignore_nulls
-        ),
+        right_on=pl.concat_str(pl.col("key"), ignore_nulls=False),
         how="full",
         maintain_order="none",
     )
